summaryrefslogtreecommitdiffstats
path: root/krdc/keycapturedialog.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 23:21:47 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 23:21:47 -0600
commitda47dd9fc60e6e0eecf609fb934eb0e2bd3ef3fb (patch)
treeb42ba87fcdfa425a31e243a62d71e1de248b6ee8 /krdc/keycapturedialog.cpp
parent4ed8d784e29102ed1659f4ccf71fcc6fb0dad5c8 (diff)
downloadtdenetwork-da47dd9fc60e6e0eecf609fb934eb0e2bd3ef3fb.tar.gz
tdenetwork-da47dd9fc60e6e0eecf609fb934eb0e2bd3ef3fb.zip
Rename many classes and header files to avoid conflicts with KDE4
Diffstat (limited to 'krdc/keycapturedialog.cpp')
-rw-r--r--krdc/keycapturedialog.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/krdc/keycapturedialog.cpp b/krdc/keycapturedialog.cpp
index 2d9f502b..9949471e 100644
--- a/krdc/keycapturedialog.cpp
+++ b/krdc/keycapturedialog.cpp
@@ -3,7 +3,7 @@
-------------------
begin : Wed Dec 25 01:20:22 CET 2002
copyright : (C) 2002-2003 by Tim Jansen
- (C) unknown (whoever wrote kshortcutdialog.cpp)
+ (C) unknown (whoever wrote tdeshortcutdialog.cpp)
(C) 2004 Nadeem Hasan <nhasan@kde.org>
email : tim@tjansen.de
***************************************************************************/
@@ -18,7 +18,7 @@
***************************************************************************/
//
// based on key capture code from tdelibs/tdeui/kshortcutdialog.cpp
//
#include "keycapturedialog.h"
@@ -91,7 +91,7 @@ bool KeyCaptureDialog::x11Event(XEvent *pEvent)
void KeyCaptureDialog::x11EventKeyPress( XEvent *pEvent )
{
// taken from kshortcutdialog.h
KKeyNative keyNative( pEvent );
uint keyModX = keyNative.mod(), keySymX = keyNative.sym();
if ((keySymX == XK_Escape) && !keyModX) {
@@ -18,7 +18,7 @@
***************************************************************************/
//
-// based on key capture code from tdelibs/tdeui/kshortcutdialog.cpp
+// based on key capture code from tdelibs/tdeui/tdeshortcutdialog.cpp
//
#include "keycapturedialog.h"
@@ -91,7 +91,7 @@ bool KeyCaptureDialog::x11Event(XEvent *pEvent)
void KeyCaptureDialog::x11EventKeyPress( XEvent *pEvent )
{
- // taken from kshortcutdialog.h
+ // taken from tdeshortcutdialog.h
KKeyNative keyNative( pEvent );
uint keyModX = keyNative.mod(), keySymX = keyNative.sym();